﻿using ZXing.Net.Maui;

namespace TestProject;

/// <summary>
/// 메인 페이지
/// </summary>
public partial class MainPage : ContentPage
{
    //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
    ////////////////////////////////////////////////////////////////////////////////////////// Public

    #region 생성자 - MainPage()

    /// <summary>
    /// 생성자
    /// </summary>
    public MainPage()
    {
        InitializeComponent();

        this.cameraLocationSwitch.Toggled             += cameraLocationSwitch_Toggled;
        this.cameraLightSwitch.Toggled                += cameraLightSwitch_Toggled;
        this.cameraBarcodeReaderView.BarcodesDetected += cameraBarcodeReaderView_BarcodesDetected;
    }

    #endregion

    //////////////////////////////////////////////////////////////////////////////////////////////////// Method
    ////////////////////////////////////////////////////////////////////////////////////////// Private

    #region 카메라 위치 스위치 토글시 처리하기 - cameraLocationSwitch_Toggled(sender, e)

    /// <summary>
    /// 카메라 위치 스위치 토글시 처리하기
    /// </summary>
    /// <param name="sender">이벤트 발생자</param>
    /// <param name="e">이벤트 인자</param>
    private void cameraLocationSwitch_Toggled(object sender, ToggledEventArgs e)
    {
        if(this.cameraLocationSwitch.IsToggled)
        {
            this.cameraBarcodeReaderView.CameraLocation = CameraLocation.Front;
        }
        else
        {
            this.cameraBarcodeReaderView.CameraLocation = CameraLocation.Rear;
        }
    }

    #endregion
    #region 카메라 조명 스위치 토글시 처리하기 - cameraLightSwitch_Toggled(sender, e)

    /// <summary>
    /// 카메라 조명 스위치 토글시 처리하기
    /// </summary>
    /// <param name="sender">이벤트 발생자</param>
    /// <param name="e">이벤트 인자</param>
    private void cameraLightSwitch_Toggled(object sender, ToggledEventArgs e)
    {
        this.cameraBarcodeReaderView.IsTorchOn = this.cameraLightSwitch.IsToggled;
    }

    #endregion
    #region 카메라 바코드 리더 뷰 바코드 탐지시 처리하기 - cameraBarcodeReaderView_BarcodesDetected(sender, e)

    /// <summary>
    /// 카메라 바코드 리더 뷰 바코드 탐지시 처리하기
    /// </summary>
    /// <param name="sender">이벤트 발생자</param>
    /// <param name="e">이벤트 인자</param>
    private void cameraBarcodeReaderView_BarcodesDetected(object sender, BarcodeDetectionEventArgs e)
    {
        Dispatcher.Dispatch
        (
            () =>
            {
                this.barcodeResultLabel.Text = $"{e.Results[0].Value}{Environment.NewLine}[{e.Results[0].Format}]";

                this.barcodeGeneratorView.Value = e.Results[0].Value;
            }
        );
    }

    #endregion
}